Checks whether the Poppins font family is available, either registered from
the bundled copies (via .onLoad) or installed system-wide. Returns FALSE
silently if the systemfonts package is not installed.
Checks whether the Poppins font family is available, either registered from
the bundled copies (via .onLoad) or installed system-wide. Returns FALSE
silently if the systemfonts package is not installed.