Skip to contents

Downloads and installs the Poppins font family from Google Fonts for system-wide use. This is optional — benviplot already bundles Poppins and registers it automatically on package load.

Requires an internet connection. After a system-wide installation, the font is available outside of R as well.

Usage

install_poppins()

Value

Invisibly returns TRUE if installation succeeds, throws an error otherwise.

Examples

if (FALSE) { # \dontrun{
install_poppins()
} # }