Returns the hex codes of a named Benvi palette. Use show_palettes() to see
the available palettes. The interface follows the
ghibli package.
Usage
benvi_palette(
pal_name = "qual_2",
n,
direction = 1,
type = c("discrete", "continuous")
)Returns the hex codes of a named Benvi palette. Use show_palettes() to see
the available palettes. The interface follows the
ghibli package.
benvi_palette(
pal_name = "qual_2",
n,
direction = 1,
type = c("discrete", "continuous")
)